==> aws-java-sdk-cognitoidp-1.10.70-sources.jar: com/amazonaws/services/cognitoidp/model/transform/LambdaConfigTypeJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidp.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * LambdaConfigTypeMarshaller
 */
public class LambdaConfigTypeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(LambdaConfigType lambdaConfigType,
            StructuredJsonGenerator jsonGenerator) {

        if (lambdaConfigType == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (lambdaConfigType.getPreSignUp() != null) {
                jsonGenerator.writeFieldName("PreSignUp").writeValue(
                        lambdaConfigType.getPreSignUp());
            }
            if (lambdaConfigType.getCustomMessage() != null) {
                jsonGenerator.writeFieldName("CustomMessage").writeValue(
                        lambdaConfigType.getCustomMessage());
            }
            if (lambdaConfigType.getPostConfirmation() != null) {
                jsonGenerator.writeFieldName("PostConfirmation").writeValue(
                        lambdaConfigType.getPostConfirmation());
            }
            if (lambdaConfigType.getPreAuthentication() != null) {
                jsonGenerator.writeFieldName("PreAuthentication").writeValue(
                        lambdaConfigType.getPreAuthentication());
            }
            if (lambdaConfigType.getPostAuthentication() != null) {
                jsonGenerator.writeFieldName("PostAuthentication").writeValue(
                        lambdaConfigType.getPostAuthentication());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static LambdaConfigTypeJsonMarshaller instance;

    public static LambdaConfigTypeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new LambdaConfigTypeJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-cognitoidp-1.11.29-sources.jar: com/amazonaws/services/cognitoidp/model/transform/LambdaConfigTypeJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidp.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * LambdaConfigTypeMarshaller
 */
public class LambdaConfigTypeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(LambdaConfigType lambdaConfigType,
            StructuredJsonGenerator jsonGenerator) {

        if (lambdaConfigType == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (lambdaConfigType.getPreSignUp() != null) {
                jsonGenerator.writeFieldName("PreSignUp").writeValue(
                        lambdaConfigType.getPreSignUp());
            }
            if (lambdaConfigType.getCustomMessage() != null) {
                jsonGenerator.writeFieldName("CustomMessage").writeValue(
                        lambdaConfigType.getCustomMessage());
            }
            if (lambdaConfigType.getPostConfirmation() != null) {
                jsonGenerator.writeFieldName("PostConfirmation").writeValue(
                        lambdaConfigType.getPostConfirmation());
            }
            if (lambdaConfigType.getPreAuthentication() != null) {
                jsonGenerator.writeFieldName("PreAuthentication").writeValue(
                        lambdaConfigType.getPreAuthentication());
            }
            if (lambdaConfigType.getPostAuthentication() != null) {
                jsonGenerator.writeFieldName("PostAuthentication").writeValue(
                        lambdaConfigType.getPostAuthentication());
            }
            if (lambdaConfigType.getDefineAuthChallenge() != null) {
                jsonGenerator.writeFieldName("DefineAuthChallenge").writeValue(
                        lambdaConfigType.getDefineAuthChallenge());
            }
            if (lambdaConfigType.getCreateAuthChallenge() != null) {
                jsonGenerator.writeFieldName("CreateAuthChallenge").writeValue(
                        lambdaConfigType.getCreateAuthChallenge());
            }
            if (lambdaConfigType.getVerifyAuthChallengeResponse() != null) {
                jsonGenerator.writeFieldName("VerifyAuthChallengeResponse")
                        .writeValue(
                                lambdaConfigType
                                        .getVerifyAuthChallengeResponse());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static LambdaConfigTypeJsonMarshaller instance;

    public static LambdaConfigTypeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new LambdaConfigTypeJsonMarshaller();
        return instance;
    }

}
